@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -298,21 +298,22 @@
 #include <Xm/XmAll.h>
 
 #include "xastir.h"
+#include "globals.h"
 #include "alert.h"
 #include "util.h"
+#include "mutex_utils.h"
 #include "snprintf.h"
 #include "wx.h"
 #include "hashtable.h"
 #include "hashtable_itr.h"
+#include "database.h"
+#include "db_funcs.h"
 
 // Must be last include file
 #include "leak_detection.h"
 
 
 
-#define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
-
-
 // New method for weather alerts, using a hash
 //
 #define ALERT_HASH_SIZE 4096
@@ -1358,8 +1359,8 @@ void alert_build_list(Message *fill)
     // an underscore.  This is to identify AE5PL's compressed
     // alerts in uncompressed clothing.
 
-    if ((strncmp(fill->call_sign,"NWS_",4) == 0) |
-        ((strncmp(fill->call_sign,"NWS-",4) == 0) &
+    if ((strncmp(fill->call_sign,"NWS_",4) == 0) ||
+        ((strncmp(fill->call_sign,"NWS-",4) == 0) &&
          (strstr(title[0], "_") == NULL)))
     {
 
