@@ -1,7 +1,7 @@
 /*
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,7 +60,7 @@
 #include "awk.h"
 #include "dbfawk.h"
 #include "snprintf.h"
-#include "maps.h"
+#include "globals.h"
 
 #include <sys/stat.h>
 
@@ -128,11 +128,10 @@ void dbfawk_free_info ( dbfawk_field_info *list)
 dbfawk_field_info *dbfawk_field_list(DBFHandle dbf, char *dbffields)
 {
   dbfawk_field_info *fi = NULL, *head = NULL, *prev;
-  int nf;
   char *sp;
 
   /* now build up the list of fields to read */
-  for (nf = 0, sp = dbffields, prev = NULL; *sp; nf++)
+  for (sp = dbffields, prev = NULL; *sp; )
   {
     char *d,*p = sp;
     char junk[XBASE_FLDHDR_SZ];
