@@ -1,8 +1,6 @@
 /*
  *
- * $Id: dlm.c,v 1.10 2018/07/14 21:32:43 MikeNix Exp $
- *
- * Copyright (C) 2018-2023 The Xastir Group
+ * Copyright (C) 2018-2026 The Xastir Group
  *
  * This file was contributed by Mike Nix.
  *
@@ -44,8 +42,9 @@
 #endif
 
 #include "xastir.h"
-#include "maps.h"    // only for MAX_FILENAME
+#include "globals.h"
 #include "main.h"
+#include "mutex_utils.h"
 
 #include "dlm.h"
 
@@ -347,7 +346,6 @@ static void DLM_queue_entry_free(struct DLM_queue_entry *q)
 static void DLM_queue_destroy(void)
 {
   struct DLM_queue_entry *next, *q;
-  int count=0;
 
   q = DLM_queue;
   while (q)
@@ -356,11 +354,9 @@ static void DLM_queue_destroy(void)
     if (q->state==DLM_Q_IDLE)
     {
       DLM_queue_entry_free(q);
-      count++;
     }
     q=next;
   }
-  //fprintf(stderr, "DLM_queue_destroy: %d entries dropped\n", count);
 }
 
 /**********************************************************
@@ -369,7 +365,6 @@ static void DLM_queue_destroy(void)
 void DLM_queue_abort_tiles(void)
 {
   struct DLM_queue_entry *next, *q;
-  int count=0;
 
   q = DLM_queue;
   while (q)
@@ -378,11 +373,9 @@ void DLM_queue_abort_tiles(void)
     if ((q->state==DLM_Q_IDLE) && (q->osm_zl>=0))
     {
       DLM_queue_entry_free(q);
-      count++;
     }
     q=next;
   }
-  //fprintf(stderr, "DLM_queue_abort_tiles: %d entries dropped\n", count);
 }
 
 /**********************************************************
@@ -391,7 +384,6 @@ void DLM_queue_abort_tiles(void)
 void DLM_queue_abort_files(void)
 {
   struct DLM_queue_entry *next, *q;
-  int count=0;
 
   q = DLM_queue;
   while (q)
@@ -400,11 +392,9 @@ void DLM_queue_abort_files(void)
     if ((q->state==DLM_Q_IDLE) && (q->osm_zl<0))
     {
       DLM_queue_entry_free(q);
-      count++;
     }
     q=next;
   }
-  //fprintf(stderr, "DLM_queue_abort_files: %d entries dropped\n", count);
 }
 
 /**********************************************************
@@ -523,11 +513,11 @@ static CURL *DLM_curl_init(char *errBuf)
   {
     if (debug_level & 8192)
     {
-      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 1);
+      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 1L);
     }
     else
     {
-      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 0);
+      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 0L);
     }
 
     curl_easy_setopt(mySession, CURLOPT_ERRORBUFFER, errBuf);
@@ -567,8 +557,11 @@ static CURL *DLM_curl_init(char *errBuf)
     //
     //     http://curl.haxx.se/mail/lib-2002-12/0103.html
     //
-    curl_easy_setopt(mySession, CURLOPT_NOSIGNAL, 1);
+    curl_easy_setopt(mySession, CURLOPT_NOSIGNAL, 1L);
 #endif // LIBCURL_VERSION_NUM
+
+    // Respect and follow http redirects
+    curl_easy_setopt(mySession, CURLOPT_FOLLOWLOCATION, 1L);
   }
 
   return(mySession);
