@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -566,10 +566,12 @@ int search_fcc_data_appl(char *callsign, FccAppl *data)
             }
             else
             {
+              // IF we aren't some bogus record with a null next field
+              // (in which we skip to the next),
               // Check whether we passed the alphabetic
               // location for the callsign.  Return if so.
-              if ( (temp[0] < line[pos]) ||
-                   ( (temp[0] == line[pos]) && (temp[1] < line[pos+1]) ) )
+              if ( line[pos] != '|' && ((temp[0] < line[pos]) ||
+                   ( (temp[0] == line[pos]) && (temp[1] < line[pos+1]))))
               {
 
                 // "Callsign Search", "Callsign Not Found!"
