@@ -1,6 +1,6 @@
 // Modification for Xastir CVS purposes
 //
-// Portions Copyright (C) 2000-2023 The Xastir Group
+// Portions Copyright (C) 2000-2026 The Xastir Group
 //
 //
 // End of modification
@@ -94,9 +94,12 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#include "xastir.h"
+#include "sound.h"
 #include "festival.h"
 #include "snprintf.h"
+#include "util.h"
+#include "xastir.h"
+
 
 // Must be last include file
 #include "leak_detection.h"
