@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -99,11 +99,11 @@ CURL *xastir_curl_init(char *errBuf)
   {
     if (debug_level & 8192)
     {
-      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 1);
+      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 1L);
     }
     else
     {
-      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 0);
+      curl_easy_setopt(mySession, CURLOPT_VERBOSE, 0L);
     }
 
 
@@ -143,9 +143,11 @@ CURL *xastir_curl_init(char *errBuf)
     //
     //     http://curl.haxx.se/mail/lib-2002-12/0103.html
     //
-    curl_easy_setopt(mySession, CURLOPT_NOSIGNAL, 1);
+    curl_easy_setopt(mySession, CURLOPT_NOSIGNAL, 1L);
 #endif // LIBCURL_VERSION_NUM
 
+    // Respect and follow http redirects
+    curl_easy_setopt(mySession, CURLOPT_FOLLOWLOCATION, 1L);
   }
 
   return(mySession);
@@ -215,6 +217,7 @@ int fetch_remote_file(char *fileimg, char *local_filename)
       fprintf(stderr, "curlerr: %s\n", curlerr);
       fprintf(stderr,
               "Perhaps a timeout? Try increasing \"Internet Map Timeout\".\n");
+      fprintf(stderr,"Could also be malformed URL, '%s'",fileimg);
     }
 
     if (ftpfile.stream)
