@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,7 +42,9 @@
 
 #include "gps.h"
 #include "main.h"
+#include "globals.h"
 #include "interface.h"
+#include "db_funcs.h"
 #include "lang.h"
 #include "util.h"
 
