@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,9 +42,11 @@
 #include "xastir.h"
 #include "igate.h"
 #include "main.h"
+#include "db_funcs.h"
 #include "interface.h"
 #include "xa_config.h"
 #include "util.h"
+#include "log_utils.h"
 
 // Must be last include file
 #include "leak_detection.h"
