@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,8 +33,11 @@
 
 #include "xastir.h"
 #include "main.h"
+#include "globals.h"
+#include "db_funcs.h"
 #include "xa_config.h"
 #include "util.h"
+#include "mutex_utils.h"
 #include "lang.h"
 #include "snprintf.h"
 
