@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,9 +27,9 @@
 #include <X11/Intrinsic.h>
 
 // For mutex debugging with Linux threads only
-#ifdef __linux__
-  #define MUTEX_DEBUG 1
-#endif  // __linux__
+//#ifdef __linux__
+//  #define MUTEX_DEBUG 1
+//#endif  // __linux__
 
 
 // This gets defined if pthreads implementation uses SIGUSR1/SIGUSR2
@@ -373,12 +373,12 @@ extern void Coordinate_calc(Widget w, XtPointer clientData, XtPointer callData);
 
 extern void HandlePendingEvents(XtAppContext app);
 extern void create_gc(Widget w);
-extern void Station_info(Widget w, XtPointer clientData, XtPointer calldata);
 extern void Station_List(Widget w, XtPointer clientData, XtPointer calldata);
 extern void Tracks_All_Clear(Widget w, XtPointer clientData, XtPointer callData);
 extern void Locate_station(Widget w, XtPointer clientData, XtPointer callData);
 extern void Locate_place(Widget w, XtPointer clientData, XtPointer callData);
 extern void Geocoder_place(Widget w, XtPointer clientData, XtPointer callData);
+extern void Configure_geocoder_settings(Widget w, XtPointer clientData, XtPointer callData);
 extern void Display_Wx_Alert(Widget w, XtPointer clientData, XtPointer callData);
 extern void Auto_msg_option(Widget w, XtPointer clientData, XtPointer calldata);
 extern void Auto_msg_set(Widget w, XtPointer clientData, XtPointer calldata);
@@ -432,6 +432,13 @@ extern void updateObjectPictureCallback(Widget w,XtPointer clientData,XtPointer
 
 extern void Draw_All_CAD_Objects(Widget w);
 
+// Nominatim geocoding configuration
+extern char nominatim_server_url[400];
+extern int nominatim_cache_enabled;
+extern int nominatim_cache_days;
+extern char nominatim_user_email[100];
+extern char nominatim_country_default[20];
+
 // unit conversion
 extern char un_alt[2+1];
 extern char un_dst[2+1];
