@@ -1,7 +1,7 @@
 /*
  *
  *
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This file was contributed by Jerry Dunmire, KA6HLD.
  *
@@ -23,7 +23,7 @@
  *
  * This file derived from map_tiger.c which has the following copyrights:
  *    Copyright (C) 1999,2000  Frank Giannandrea
- *    Copyright (C) 2000-2023 The Xastir Group
+ *    Copyright (C) 2000-2026 The Xastir Group
  */
 
 
@@ -62,6 +62,7 @@
 #include <math.h>
 
 #include "xastir.h"
+#include "globals.h"
 #include "maps.h"
 #include "fetch_remote.h"
 #include "util.h"
@@ -75,8 +76,6 @@
 #include "dlm.h"
 #include "map_OSM.h"
 
-#define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
-
 #ifdef HAVE_MAGICK
   #if HAVE_SYS_TIME_H
     #include <sys/time.h>
@@ -1159,26 +1158,8 @@ void draw_OSM_tiles (Widget w,
     serverURL[strlen(serverURL) - 1] = '\0';
   }
 
-  // Create a shorter filename for display (one that fits the
-  // status line more closely).  Allow space for the
-  // "Indexing " or "Loading " strings.
-  if (strlen(filenm) > (41 - 9))
-  {
-    int avail = 41 - 11;
-    int new_len = strlen(filenm) - avail;
-
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "..%s",
-                    &filenm[new_len]);
-  }
-  else
-  {
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "%s",
-                    filenm);
-  }
+  // Create a shorter filename for display
+  short_filename_for_status(filenm, short_filenm, sizeof(short_filenm));
 
   GetExceptionInfo(&exception);
 
@@ -1516,26 +1497,8 @@ void draw_OSM_map (Widget w,
   // initialize this
   local_filename[0]='\0';
 
-  // Create a shorter filename for display (one that fits the
-  // status line more closely).  Subtract the length of the
-  // "Indexing " and/or "Loading " strings as well.
-  if (strlen(filenm) > (41 - 9))
-  {
-    int avail = 41 - 11;
-    int new_len = strlen(filenm) - avail;
-
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "..%s",
-                    &filenm[new_len]);
-  }
-  else
-  {
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "%s",
-                    filenm);
-  }
+  // Create a shorter filename for display
+  short_filename_for_status(filenm, short_filenm, sizeof(short_filenm));
 
   xastir_snprintf(map_it,
                   sizeof(map_it),
