@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,6 +57,7 @@
 #include <math.h>
 
 #include "xastir.h"
+#include "globals.h"
 #include "maps.h"
 #include "alert.h"
 #include "fetch_remote.h"
@@ -70,8 +71,6 @@
 
 #include "map_cache.h"
 
-#define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
-
 #ifdef HAVE_MAGICK
   #if HAVE_SYS_TIME_H
     #include <sys/time.h>
@@ -221,26 +220,8 @@ void draw_WMS_map (Widget w,
     }
   }
 
-  // Create a shorter filename for display (one that fits the
-  // status line more closely).  Subtract the length of the
-  // "Indexing " and/or "Loading " strings as well.
-  if (strlen(filenm) > (41 - 9))
-  {
-    int avail = 41 - 11;
-    int new_len = strlen(filenm) - avail;
-
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "..%s",
-                    &filenm[new_len]);
-  }
-  else
-  {
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "%s",
-                    filenm);
-  }
+  // Create a shorter filename for display
+  short_filename_for_status(filenm, short_filenm, sizeof(short_filenm));
 
   xastir_snprintf(map_it,
                   sizeof(map_it),
@@ -356,7 +337,7 @@ void draw_WMS_map (Widget w,
 
 // This specifies a bounding box based on square pixels.
   xastir_snprintf(tmpstr, sizeof(tmpstr),
-                  "&BBOX=%8.5f,%7.5f,%8.5f,%7.5f",
+                  "&BBOX=%08.5f,%07.5f,%08.5f,%07.5f",
                   left,   // Lower left
                   bottom, // Lower left
                   right,  // Upper right
