@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,6 +57,7 @@
 #include <math.h>
 
 #include "xastir.h"
+#include "globals.h"
 #include "maps.h"
 #include "alert.h"
 #include "util.h"
@@ -72,8 +73,6 @@
 
 
 
-#define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
-
 //NOTE:  This function has a problem if a non-pop file is labeled
 //with a ".pop" extension.  It causes a segfault in Xastir.  More
 //error checking needs to be done in order to prevent this.
@@ -144,26 +143,8 @@ void draw_pop_map (Widget w,
 
   xastir_snprintf(file, sizeof(file), "%s/%s", dir, filenm);
 
-  // Create a shorter filename for display (one that fits the
-  // status line more closely).  Subtract the length of the
-  // "Indexing " and/or "Loading " strings as well.
-  if (strlen(filenm) > (41 - 9))
-  {
-    int avail = 41 - 11;
-    int new_len = strlen(filenm) - avail;
-
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "..%s",
-                    &filenm[new_len]);
-  }
-  else
-  {
-    xastir_snprintf(short_filenm,
-                    sizeof(short_filenm),
-                    "%s",
-                    filenm);
-  }
+  // Create a shorter filename for display
+  short_filename_for_status(filenm, short_filenm, sizeof(short_filenm));
 
   // Screen view
   min_lat = SE_corner_latitude;
@@ -646,14 +627,7 @@ FINISH:
               fprintf(stderr,"%s\t%s\n", lat_str, long_str);
             }
 
-            // Convert to screen coordinates.  Careful
-            // here!  The format conversions you'll need
-            // if you try to compress this into two
-            // lines will get you into trouble.
-            x = coord_lon - NW_corner_longitude;
-            y = coord_lat - NW_corner_latitude;
-            x /= scale_x;
-            y /= scale_y;
+            convert_xastir_to_screen_coordinates(coord_lon, coord_lat, &x, &y);
 
             ok = 1;
 
