@@ -1,7 +1,7 @@
 /*
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -138,19 +138,26 @@ int main(int argc, char *argv[])
   //    int args;
   awk_symtab *symtbl;
   /* variables to bind to: */
-  int color = 0;
-  int lanes = 0;
-  int font_size = 0;
   char dbfinfo[1024];        /* list of DBF field names */
   char dbffields[1024];    /* subset we want to read */
   char name[128];
   char key[128];
   char symbol[4];
+  int color = 0;
+  int lanes = 0;
   int filled = 5;
   int pattern=0;
   int display_level = 1234;
+  int min_display_level = 0;
   int label_level = 9;
+  int fill_style=0, fill_color=0;
+  int fill_stipple=0;
   int label_color = 8;
+  int font_size = 0;
+  int label_method = 0;
+  double label_lon = 0.0;
+  double label_lat = 0.0;
+
   char *dir = NULL,*file = NULL,*dfile = NULL;
   dbfawk_sig_info *si = NULL, *sigs = NULL;
 
@@ -203,11 +210,18 @@ int main(int argc, char *argv[])
   awk_declare_sym(symtbl,"key",STRING,key,sizeof(key));
   awk_declare_sym(symtbl,"symbol",STRING,symbol,sizeof(symbol));
   awk_declare_sym(symtbl,"filled",INT,&filled,sizeof(filled));
+  awk_declare_sym(symtbl,"fill_style",INT,&fill_style,sizeof(fill_style));
+  awk_declare_sym(symtbl,"fill_color",INT,&fill_color,sizeof(fill_color));
+  awk_declare_sym(symtbl,"fill_stipple",INT,&fill_stipple,sizeof(fill_stipple));
   awk_declare_sym(symtbl,"pattern",INT,&pattern,sizeof(pattern));
   awk_declare_sym(symtbl,"display_level",INT,&display_level,sizeof(display_level));
+  awk_declare_sym(symtbl,"min_display_level",INT,&min_display_level,sizeof(min_display_level));
   awk_declare_sym(symtbl,"label_level",INT,&label_level,sizeof(label_level));
   awk_declare_sym(symtbl,"label_color",INT,&label_color,sizeof(label_color));
   awk_declare_sym(symtbl,"font_size",INT,&font_size,sizeof(font_size));
+  awk_declare_sym(symtbl,"label_method",INT,&label_method,sizeof(label_method));
+  awk_declare_sym(symtbl,"label_lon",FLOAT,&label_lon,sizeof(label_lon));
+  awk_declare_sym(symtbl,"label_lat",FLOAT,&label_lat,sizeof(label_lat));
 
   if (dfile)          /* parse dbf file */
   {
@@ -264,11 +278,18 @@ int main(int argc, char *argv[])
       fprintf(stderr,"color=%d, ", color);
       fprintf(stderr,"lanes=%d, ", lanes);
       fprintf(stderr,"filled=%d, ",filled);
+      fprintf(stderr,"fill_style=%d ",fill_style);
+      fprintf(stderr,"fill_color=%d ",fill_color);
+      fprintf(stderr,"fill_stipple=%d ",fill_stipple);
       fprintf(stderr,"pattern=%d, ",pattern);
       fprintf(stderr,"display_level=%d, ",display_level);
+      fprintf(stderr,"min_display_level=%d, ",min_display_level);
       fprintf(stderr,"font_size=%d, ", font_size);
-      fprintf(stderr,"label_level=%d\n",label_level);
-      fprintf(stderr,"label_color=%d\n",label_color);
+      fprintf(stderr,"label_level=%d, ",label_level);
+      fprintf(stderr,"label_color=%d, ",label_color);
+      fprintf(stderr,"label_method=%d, ",label_method);
+      fprintf(stderr,"label_lon=%lf, ",label_lon);
+      fprintf(stderr,"label_lat=%lf\n",label_lat);
       //    print_symtbl(symtbl);
     }
     DBFClose(dbf);
