@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,11 +36,14 @@
 
 #include "xastir.h"
 #include "main.h"
+#include "db_funcs.h"
+#include "db_gui.h"
 #include "lang.h"
 #include "objects.h"
 #include "popup.h"
 #include "fetch_remote.h"
 #include "util.h"
+#include "mutex_utils.h"
 #include "xa_config.h"
 
 // Must be last include file
