@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,7 +48,9 @@
 
 #include "xastir.h"
 #include "main.h"
+#include "db_funcs.h"
 #include "util.h"
+#include "mutex_utils.h"
 
 // Must be last include file
 #include "leak_detection.h"
@@ -92,7 +94,8 @@ void view_message_print_record(Message *m_fill)
 
 
   // Make sure it's within our distance range we have set
-  distance = distance_from_my_station(m_fill->from_call_sign,temp_my_course);
+  distance = distance_from_my_station(m_fill->from_call_sign,temp_my_course,
+                                      english_units);
 
   if (Read_messages_mine_only
       || (!Read_messages_mine_only
@@ -223,7 +226,8 @@ void all_messages(char from, char *call_sign, char *from_call, char *message)
   if (Read_messages_mine_only
       || (!Read_messages_mine_only
           && ((vm_range == 0)
-              || (distance_from_my_station(call_sign,temp_my_course) <= vm_range)) ) )
+              || (distance_from_my_station(call_sign,temp_my_course,
+                                           english_units) <= vm_range)) ) )
   {
 
     // Check that it's coming from the correct type of interface
