@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,8 +42,10 @@
 #include "xastir.h"
 #include "wx.h"
 #include "main.h"
+#include "db_funcs.h"
 #include "alert.h"
 #include "lang.h"
+#include "mutex_utils.h"
 
 #include <Xm/XmAll.h>
 #ifdef HAVE_XBAE_MATRIX_H
