@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,6 +39,7 @@
 #include "interface.h"
 #include "xastir.h"
 #include "main.h"
+#include "db_funcs.h"
 #include "util.h"
 #include "bulletin_gui.h"
 #include "list_gui.h"
@@ -46,10 +47,12 @@
 #include "draw_symbols.h"
 #include "maps.h"
 #include "track_gui.h"
-#include "geo.h"
 #include "snprintf.h"
 #include "objects.h"
+#include "objects_gui.h"
 #include "db_gis.h"
+#include "ambiguity_utils.h"
+#include "cad_objects.h"
 
 // Must be last include file
 #include "leak_detection.h"
@@ -639,8 +642,15 @@ void save_data(void)
     store_string (fout, "SOUND_DIR", SOUND_DIR);
     store_string (fout, "GROUP_DATA_FILE", group_data_file);
     store_string (fout, "GNIS_FILE", locate_gnis_filename);
-    store_string (fout, "GEOCODE_FILE", geocoder_map_filename);
-    store_int (fout, "SHOW_FIND_TARGET", show_destination_mark);
+
+#ifdef HAVE_NOMINATIM
+    /* Nominatim geocoding configuration */
+    store_string (fout, "NOMINATIM_SERVER_URL", nominatim_server_url);
+    store_int (fout, "NOMINATIM_CACHE_ENABLED", nominatim_cache_enabled);
+    store_int (fout, "NOMINATIM_CACHE_DAYS", nominatim_cache_days);
+    store_string (fout, "NOMINATIM_USER_EMAIL", nominatim_user_email);
+    store_string (fout, "NOMINATIM_COUNTRY_DEFAULT", nominatim_country_default);
+#endif
 
     /* maps */
     store_int (fout, "MAPS_LONG_LAT_GRID", long_lat_grid);
@@ -1504,8 +1514,8 @@ void load_data_or_default(void)
   my_trail_diff_color = get_int ("MY_TRAIL_DIFF_COLOR", 0, 1, 0);
 
   /* default values */
-  screen_width = get_long ("SCREEN_WIDTH", 61l, 10000l, 590l);
-  screen_height = get_long ("SCREEN_HEIGHT", 1l, 10000l, 420l);
+  screen_width = get_long ("SCREEN_WIDTH", 61l, 10000l, DEFAULT_STARTUP_SCREEN_WIDTH);
+  screen_height = get_long ("SCREEN_HEIGHT", 1l, 10000l, DEFAULT_STARTUP_SCREEN_HEIGHT);
 
   //    screen_x_offset = (Position)get_int ("SCREEN_X_OFFSET", 0, 10000, 0);
   //    screen_y_offset = (Position)get_int ("SCREEN_Y_OFFSET", 0, 10000, 0);
@@ -1695,16 +1705,33 @@ void load_data_or_default(void)
                     get_data_base_dir ("GNIS/WA.gnis"));
   }
 
-  if (!get_string ("GEOCODE_FILE", geocoder_map_filename, sizeof(geocoder_map_filename))
-      || geocoder_map_filename[0] == '\0')
+
+#ifdef HAVE_NOMINATIM
+  /* Nominatim geocoding configuration */
+  if (!get_string ("NOMINATIM_SERVER_URL", nominatim_server_url, sizeof(nominatim_server_url))
+      || nominatim_server_url[0] == '\0')
   {
-    xastir_snprintf(geocoder_map_filename,
-                    sizeof(geocoder_map_filename),
+    xastir_snprintf(nominatim_server_url,
+                    sizeof(nominatim_server_url),
                     "%s",
-                    get_data_base_dir ("GNIS/geocode"));
+                    "https://nominatim.openstreetmap.org");
   }
 
-  show_destination_mark = get_int ("SHOW_FIND_TARGET", 0, 1, 1);
+  nominatim_cache_enabled = get_int ("NOMINATIM_CACHE_ENABLED", 0, 1, 1);
+  nominatim_cache_days = get_int ("NOMINATIM_CACHE_DAYS", 0, 365, 30);
+
+  // Empty string is ok here
+  if (!get_string ("NOMINATIM_USER_EMAIL", nominatim_user_email, sizeof(nominatim_user_email)))
+  {
+    nominatim_user_email[0] = '\0';
+  }
+
+  // Empty string is ok here
+  if (!get_string ("NOMINATIM_COUNTRY_DEFAULT", nominatim_country_default, sizeof(nominatim_country_default)))
+  {
+    nominatim_country_default[0] = '\0';
+  }
+#endif
 
   /* maps */
   long_lat_grid = get_int ("MAPS_LONG_LAT_GRID", 0, 1, 1);
