@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2023 The Xastir Group
+ * Copyright (C) 2000-2026 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,8 @@
 
 
 #define MAX_VALUE 300
+#define DEFAULT_STARTUP_SCREEN_WIDTH 590l
+#define DEFAULT_STARTUP_SCREEN_HEIGHT 420l
 
 extern time_t next_time;
 
